pub enum FileError {
Io(Error),
NotFound {
pattern: String,
locations: String,
},
Parse {
path: PathBuf,
format: &'static str,
source: Box<dyn Error + Send + Sync>,
},
UnsupportedFormat {
format: String,
},
Serialization(String),
}👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Errors that can occur when working with configuration files.
Variants
Io(Error)
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
IO error occurred.
NotFound
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
File not found in any search location.
Fields
Parse
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Parse error for a specific format.
Fields

path: PathBuf👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Path to the file.
UnsupportedFormat
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Format not supported (feature not enabled).
Fields
Serialization(String)
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Serialization error.