ConfigFile

Struct ConfigFile 

pub struct ConfigFile {
    pub path: PathBuf,
    pub tier: ConfigTier,
    pub format: Format,
    pub content: Option<String>,
}
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
A discovered configuration file.

Fields

path: PathBuf
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Full path to the file.

tier: ConfigTier
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Configuration tier (determines priority).

format: Format
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

File format.

content: Option<String>
👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Cached content (loaded on demand).

Implementations

Source

impl ConfigFile

pub fn name(&self) -> Option<&str>

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Get the file name.

pub fn read(&mut self) -> Result<&str>

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Read the file content.

Errors

Returns an error if the file cannot be read.

Panics

Panics if the content was not set after reading (this should never happen in practice).

pub fn parse<T: DeserializeOwned>(&mut self) -> Result<T>

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Parse the file into a type T.

Errors

Returns an error if the file cannot be read or parsed.

pub fn parse_uncached<T: DeserializeOwned>(&self) -> Result<T>

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Parse without caching content.

Errors

Returns an error if the file cannot be read or parsed.

pub fn exists(&self) -> bool

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Check if the file exists.

pub fn modified(&self) -> Result<SystemTime>

👎Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API

Get the file modification time.

Errors

Returns an error if file metadata cannot be retrieved.