pub struct FileFinderState { /* private fields */ }๐Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
Stateful file finder after configuration.
Implementations
Sourceimpl FileFinderState
impl FileFinderState
Sourcepub fn find(&self) -> Result<ConfigFiles>
๐Deprecated since 2.0.1: use cfgmatic-source crate instead, which provides a unified configuration source API
pub fn find(&self) -> Result<ConfigFiles>